@@ -307,7 +307,7 @@ get_cookies (SoupCookieJar *jar, SoupURI *uri, gboolean for_http, gboolean copy_
 
 	priv = soup_cookie_jar_get_instance_private (jar);
 
-	if (!uri->host)
+	if (!uri->host || !uri->host[0])
 		return NULL;
 
 	/* The logic here is a little weird, but the plan is that if
@@ -714,6 +714,10 @@ soup_cookie_jar_request_queued (SoupSessionFeature *feature,
 					 "Set-Cookie",
 					 G_CALLBACK (process_set_cookie_header),
 					 feature);
+        soup_message_add_status_code_handler (msg, "got-informational",
+                                              SOUP_STATUS_SWITCHING_PROTOCOLS,
+                                              G_CALLBACK (process_set_cookie_header),
+                                              feature);
 }
 
 static void
